| Title: | HTSlib high-throughput sequencing library as an R package |
|---|---|
| Description: | This package provides version 1.18 of the 'HTSlib' C library for high-throughput sequence analysis. The package is primarily useful to developers of other R packages who wish to make use of HTSlib. Motivation and instructions for use of this package are in the vignette, vignette(package="Rhtslib", "Rhtslib"). |
| Authors: | Nathaniel Hayden [led, aut], Martin Morgan [aut], Hervé Pagès [aut, cre], Tomas Kalibera [ctb], Jeroen Ooms [ctb] |
| Maintainer: | Hervé Pagès <[email protected]> |
| License: | LGPL (>= 2) |
| Version: | 3.9.0 |
| Built: | 2026-05-29 10:15:28 UTC |
| Source: | https://github.com/bioc/Rhtslib |
This package is interesting to package developers only, and provides a compiled HTSlib for developers to use in their own packages. See the vignette for instructions on use.
Instructions for use are in the vignette, available with
browseVignettes(package="Rhtslib")
Nathaniel Hayden [email protected]
The HTSlib included in the package is based on release 1.18 of HTSlib found at https://github.com/samtools/htslib/releases/
packageDescription('Rhtslib') Rhtslib:::htsVersion()packageDescription('Rhtslib') Rhtslib:::htsVersion()
This function prints values for PKG_LIBS and
PKG_CPPFLAGS variables for use in Makevars files.
See vignette("Rhtslib") for details. The environment
variable RHTSLIB_RPATH can be used to over-ride the
inferred location of the installed package.
pkgconfig(opt = c("PKG_LIBS", "PKG_CPPFLAGS"))pkgconfig(opt = c("PKG_LIBS", "PKG_CPPFLAGS"))
opt |
A scalar character from the list of available options;
default is |
The function prints the PKG_LIBS or PKG_CPPFLAGS value
and returns an invisible NULL.
Nathaniel Hayden mailto:[email protected]
pkgconfig("PKG_LIBS") pkgconfig("PKG_CPPFLAGS")pkgconfig("PKG_LIBS") pkgconfig("PKG_CPPFLAGS")